@@ -24,64 +24,34 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-eventbridge-kinesisstreams`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.eventbridgekinesisstreams`|
 
-## Overview
-
 This AWS Solutions Construct implements an Amazon EventBridge rule to send data to an Amazon Kinesis Data Stream
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps, Duration } from 'aws-cdk-lib';
-import { EventbridgeToKinesisStreams, EventbridgeToKinesisStreamsProps } from "@aws-solutions-constructs/aws-eventbridge-kinesisstreams";
-import * as events from 'aws-cdk-lib/aws-events';
+import * as cdk from '@aws-cdk/core';
+import {EventbridgeToKinesisStreams, EventbridgeToKinesisStreamsProps} from "@aws-solutions-constructs/aws-eventbridge-kinesisstreams";
 
-const constructProps: EventbridgeToKinesisStreamsProps = {
-  eventRuleProps: {
-    schedule: events.Schedule.rate(Duration.minutes(5)),
-  }
+const props: EventbridgeToKinesisStreamsProps = {
+    eventRuleProps: {
+      schedule: events.Schedule.rate(Duration.minutes(5)),
+    }
 };
 
-new EventbridgeToKinesisStreams(this, 'test-eventbridge-kinesis-streams', constructProps);
+new EventbridgeToKinesisStreams(this, 'test-eventbridge-kinesis-streams', props);
 ```
 
-Python
+## Initializer
 
-```Python
-from aws_solutions_constructs.aws_eventbridge_kinesis_streams import EventbridgeToKinesisStreams, EventbridgeToKinesisStreamsProps
-from aws_cdk import (
-    aws_events as events,
-    Duration,
-    Stack
-)
-from constructs import Construct
-
-EventbridgeToKinesisStreams(self, 'test-eventbridge-kinesis-streams',
-    event_rule_props=events.RuleProps(
-        schedule=events.Schedule.rate(Duration.minutes(5)),
-    ))
+```text
+new EventbridgeToKinesisStreams(scope: Construct, id: string, props: EventbridgeToKinesisStreamsProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.Duration;
-import software.amazon.awscdk.services.events.*;
-import software.amazon.awsconstructs.services.eventbridgekinesisstreams.*;
-
-new EventbridgeToKinesisStreams(this, "test-eventbridge-kinesis-streams",
-        new EventbridgeToKinesisStreamsProps.Builder()
-                .eventRuleProps(new RuleProps.Builder()
-                        .schedule(Schedule.rate(Duration.minutes(5)))
-                        .build())
-                .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`EventbridgeToKinesisStreamsProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -123,7 +93,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -135,30 +105,28 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
-import aws_cdk.core
+import constructs
 
 
 class EventbridgeToKinesisStreams(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-eventbridge-kinesisstreams.EventbridgeToKinesisStreams",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_rule_props: aws_cdk.aws_events.RuleProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_stream_props: typing.Any = None,
@@ -176,22 +144,6 @@ class EventbridgeToKinesisStreams(
         :access: public
         :summary: Constructs a new instance of the EventbridgeToKinesisStreams class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToKinesisStreamsProps(
             event_rule_props=event_rule_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
@@ -203,29 +155,29 @@ class EventbridgeToKinesisStreams(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRole")
     def events_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "eventsRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -247,9 +199,9 @@ class EventbridgeToKinesisStreamsProps:
     def __init__(
         self,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_rule_props: aws_cdk.aws_events.RuleProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_stream_props: typing.Any = None,
@@ -268,24 +220,6 @@ class EventbridgeToKinesisStreamsProps:
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(event_bus_props, dict):
             event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
-        if __debug__:
-            def stub(
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
-            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
-            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
-            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
-            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
-            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
